# paquo changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).


## [Unreleased]
...

## [0.1.0] - 2020-08-12
### Added
- initial release of paquo


[Unreleased]: https://github.com/bayer-science-for-a-better-life/paquo/compare/v0.1.0...HEAD
[0.1.0]: https://github.com/bayer-science-for-a-better-life/paquo/tree/v0.1.0

